==> keybind_extensions_v1.2.0.zip: keybind_extensions/README.md <==
# Keybind Extensions

More possible functions for key binding.

## Features

### Camera

Toggle, start, and a stop a middle-button-like mode where the planet follows the pointer.  These only uses the regular keypress event keybinding logic.

Hold to pan operates closer to the middle mouse button.  I've found regular keys awkward to use this way, but space or an underused modifier may be more comfortable.

### Focus planet 1-16.

There is also a patch that makes next and previous planet work always focus a planet when you were focused on the sun.

### Fixed planet anchors

Look at...

- North pole
- South pole
- Equator, 0 degrees
- Equator, 90 degrees
- Equator, 180 degrees
- Equator, 270 degrees

### Specatator Vision

- All players
- Previous player
- Next player
- Player N (1-10)

### Selection

Select all on screen (double tap for planet)

- Bot
- Tank (aka vehicles)
- Fighter
- Scout

### Selection Edit

Only X in Selection and Remove X from Selection:

- Construction (e.g. combat fabs)
- Bot
- Tank (aka vehicles)
- Heavy (e.g. infernos)
- Land
- Air
- Fighter
- Scout
- Naval
- Orbital
- Advanced

### Alternate ESC/Back

I tend to hit ESC too many times and end up with an option menu.  Breaks out all the pieces.  Tip: keep the basic version bound to something in case the mod gets turned off for any reason.

- Navigate back (no menu)
- Open option menu
- Close option menu
- Toggle option menu
- Close chronocam
- Cancel selection
- Clear build sequence
- End fab mode
- End command mode

==> keybind_extensions_v1.3.0.zip: keybind_extensions/README.md <==
# Keybind Extensions

More possible functions for key binding.

## Features

### Camera

Toggle, start, and a stop a middle-button-like mode where the planet follows the pointer.  These only uses the regular keypress event keybinding logic.

Hold to pan operates closer to the middle mouse button.  I've found regular keys awkward to use this way, but space or an underused modifier may be more comfortable.

### Focus planet 1-16.

There is also a patch that makes next and previous planet work always focus a planet when you were focused on the sun.

### Fixed planet anchors

Look at...

- North pole
- South pole
- Equator, 0 degrees
- Equator, 90 degrees
- Equator, 180 degrees
- Equator, 270 degrees

### Spectator Vision

- All players
- Previous player
- Next player
- Player N (1-10)

### Selection

Select all on screen (double tap for planet)

- Bot
- Tank (aka vehicles)
- Fighter
- Scout

### Selection Edit

- Only one in selection (double tap to track)
- Halve selection (within each unit type)

Only X in Selection and Remove X from Selection:

- Construction (e.g. combat fabs)
- Bot
- Tank (aka vehicles)
- Heavy (e.g. infernos)
- Land
- Air
- Fighter
- Scout
- Naval
- Orbital
- Advanced

### Alternate ESC/Back

I tend to hit ESC too many times and end up with an option menu.  Breaks out all the pieces.  Tip: keep the basic version bound to something in case the mod gets turned off for any reason.

- Navigate back (no menu)
- Open option menu
- Close option menu
- Toggle option menu
- Close chronocam
- Cancel selection
- Clear build sequence
- End fab mode
- End command mode
